# CHANGELOG


## v0.2.0 (2025-04-18)

### Chores

- Update changelog for 0.1.1
  ([`24d7139`](https://github.com/veris-ai/veris-python-sdk/commit/24d713943737abcea6394258e5129ae0a55cb869))

- Update semantic release config
  ([`6f745e0`](https://github.com/veris-ai/veris-python-sdk/commit/6f745e09263703cfe034ba688b96e4da50759889))

### Continuous Integration

- Add workflows for release ([#3](https://github.com/veris-ai/veris-python-sdk/pull/3),
  [`3c160e7`](https://github.com/veris-ai/veris-python-sdk/commit/3c160e7e928ed1efb42825b767084df5d451edb5))

- Fix publish ci workflow ([#4](https://github.com/veris-ai/veris-python-sdk/pull/4),
  [`47f23e1`](https://github.com/veris-ai/veris-python-sdk/commit/47f23e19cd04b60ab0ae087b6d70b4748350393c))

### Features

- Remove dependencies and use linter ([#2](https://github.com/veris-ai/veris-python-sdk/pull/2),
  [`4b8c43b`](https://github.com/veris-ai/veris-python-sdk/commit/4b8c43b551265ff9c994f53d29a7ef185b7e3286))


## v0.1.1 (2025-04-17)

### Features

- Updates to package for publishing ([#1](https://github.com/veris-ai/veris-python-sdk/pull/1),
  [`c6f460e`](https://github.com/veris-ai/veris-python-sdk/commit/c6f460ea6e2f8472c120370a14f67f1d8c28626c))
